EventRecord class
An immutable app event record captured by an event watcher
(e.g. MagicEventWatcher shipped in the magic package).
Constructors
Properties
- eventType → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- listenerCount → int?
-
Number of listeners notified at dispatch time, when available.
final
-
payload
→ Map<
String, dynamic> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- time → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited