attributedHeuristically property
True when the adapter could not exactly match this response to its request (concurrent requests in flight). The attribution is best-effort FIFO.
Implementation
final bool attributedHeuristically;
True when the adapter could not exactly match this response to its request (concurrent requests in flight). The attribution is best-effort FIFO.
final bool attributedHeuristically;