endUs property
Monotonic microsecond timestamp (from FlutterTimeline.now's clock) when the response arrived, when the capturing adapter tracks one.
Implementation
final int? endUs;
Monotonic microsecond timestamp (from FlutterTimeline.now's clock) when the response arrived, when the capturing adapter tracks one.
final int? endUs;