startUs property
Monotonic microsecond timestamp (from FlutterTimeline.now's clock) when the request was sent, when the capturing adapter tracks one.
Implementation
final int? startUs;
Monotonic microsecond timestamp (from FlutterTimeline.now's clock) when the request was sent, when the capturing adapter tracks one.
final int? startUs;