MagicCacheRecord class

An immutable Magic cache operation record captured by MagicCacheWatcher (shipped in magic package).

Constructors

MagicCacheRecord({required String operation, required String key, required DateTime time, Duration? ttl})

Properties

hashCode int
The hash code for this object.
no setterinherited
key String
final
operation String
'put' | 'get' | 'forget' | 'hit' | 'miss'
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time DateTime
final
ttl Duration?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited