clearFramePerf static method

void clearFramePerf()

Clear only the frame-perf buffer.

Public and NOT @visibleForTesting: a measurement session needs to zero this buffer from production code (another package assigns this into a session-reset hook) without wiping the HTTP, log and exception history a developer may also be reading, which clear would do.

Implementation

static void clearFramePerf() => _framePerf.clear();