ExceptionRecord class

An immutable exception record captured by ExceptionWatcher.

Constructors

ExceptionRecord({required String exceptionType, required String message, required DateTime time, String? stackTrace, String? isolate})

Properties

exceptionType String
final
hashCode int
The hash code for this object.
no setterinherited
isolate String?
final
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace String?
final
time DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited