GateRecord class

An immutable authorization gate check record captured by a gate watcher (e.g. MagicGateWatcher shipped in the magic package).

Constructors

GateRecord({required String ability, required bool result, required List<Object?> arguments, required DateTime time, String? userId})

Properties

ability String
final
arguments List<Object?>
final
hashCode int
The hash code for this object.
no setterinherited
result bool
True when the gate allowed the action; false when denied.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time DateTime
final
userId String?
The authenticated user's ID at check time, when available.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited