HttpRequestRecord class

An immutable HTTP request/response record captured by a TelescopeHttpAdapter.

Constructors

HttpRequestRecord({required String url, required String method, required int statusCode, required int durationMs, required bool isError, required DateTime timestamp, Map<String, String>? requestHeaders, String? requestBody, String? responseBody, bool attributedHeuristically = false})

Properties

attributedHeuristically → bool
True when the adapter could not exactly match this response to its request (concurrent requests in flight). The attribution is best-effort FIFO.
final
durationMs → int
final
hashCode → int
The hash code for this object.
no setterinherited
isError → bool
final
method → String
final
requestBody → String?
final
requestHeaders → Map<String, String>?
final
responseBody → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int
final
timestamp → DateTime
final
url → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited