LogRecordEntry class

An immutable log record captured by LogWatcher.

Constructors

LogRecordEntry({required String level, required int levelValue, required String message, required String loggerName, required DateTime time, String? error, String? stackTrace})
LogRecordEntry.fromLogRecord(LogRecord r)
factory

Properties

error → String?
final
hashCode → int
The hash code for this object.
no setterinherited
level → String
final
levelValue → int
final
loggerName → String
final
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → String?
final
time → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited