MagicModelRecord class

An immutable Magic model lifecycle event captured by MagicModelWatcher (shipped in magic package via TelescopePlugin.registerWatcher).

Constructors

MagicModelRecord({required String modelClass, required String event, required String modelKey, required DateTime time, Map<String, dynamic>? attributes})

Properties

attributes Map<String, dynamic>?
final
event String
'created' | 'saved' | 'deleted'
final
hashCode int
The hash code for this object.
no setterinherited
modelClass String
final
modelKey String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited